@@ -1,4 +1,5 @@
-# Copyright (c) 2013 Rackspace, Inc.
+# Copyright (c) 2014 Rackspace, Inc.
+# Copyright 2014 Catalyst IT Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may not
 # use this file except in compliance with the License.  You may obtain a copy
@@ -12,7 +13,13 @@
 # License for the specific language governing permissions and limitations under
 # the License.
 
-import falcon
+from oslo_log import log as logging
+
+from zaqar.i18n import _
+from zaqar.transport import utils
+from zaqar.transport.wsgi import errors as wsgi_errors
+
+LOG = logging.getLogger(__name__)
 
 
 class Resource(object):
@@ -23,8 +30,10 @@ class Resource(object):
         self._driver = driver
 
     def on_get(self, req, resp, **kwargs):
-        resp.status = (falcon.HTTP_204 if self._driver.is_alive()
-                       else falcon.HTTP_503)
-
-    def on_head(self, req, resp, **kwargs):
-        resp.status = falcon.HTTP_204
+        try:
+            resp_dict = self._driver.health()
+            resp.text = utils.to_json(resp_dict)
+        except Exception:
+            description = _('Health status could not be read.')
+            LOG.exception(description)
+            raise wsgi_errors.HTTPServiceUnavailable(description)
