@@ -63,7 +63,7 @@ class Listing(object):
         :returns: HTTP | 200
         """
 
-        LOG.debug(u'LIST flavors for project_id %s', project_id)
+        LOG.debug('LIST flavors for project_id %s', project_id)
         store = {}
         request.get_param('marker', store=store)
         request.get_param_as_int('limit', store=store)
@@ -110,7 +110,7 @@ class Listing(object):
 
         results['flavors'] = flavors
 
-        response.body = transport_utils.to_json(results)
+        response.text = transport_utils.to_json(results)
         response.status = falcon.HTTP_200
 
 
@@ -142,7 +142,7 @@ class Resource(object):
         :returns: HTTP | [200, 404]
         """
 
-        LOG.debug(u'GET flavor - name: %s', flavor)
+        LOG.debug('GET flavor - name: %s', flavor)
         data = None
 
         try:
@@ -162,7 +162,7 @@ class Resource(object):
 
         data['href'] = request.path
 
-        response.body = transport_utils.to_json(data)
+        response.text = transport_utils.to_json(data)
 
     def _check_pools_exists(self, pool_list):
         if pool_list is not None:
@@ -188,22 +188,24 @@ class Resource(object):
 
     def _on_put_by_pool_list(self, request, response, project_id,
                              flavor, pool_list):
-        LOG.debug(u'PUT flavor - name by flavor: %s', flavor)
+        LOG.debug('PUT flavor - name by flavor: %s', flavor)
         # NOTE(gengchc2): If configuration flavor is used by the new schema,
         # a list of pools is required.
         if len(pool_list) == 0:
             response.status = falcon.HTTP_400
             response.location = request.path
-            raise falcon.HTTPBadRequest(_('Unable to create'), 'Bad Request')
+            raise falcon.HTTPBadRequest(
+                title=_('Unable to create'), description='Bad Request')
         # NOTE(gengchc2): Check if pools in the pool_list exist.
         try:
             self._check_pools_exists(pool_list)
         except errors.PoolDoesNotExist as ex:
-            description = (_(u'Flavor %(flavor)s could not be created, '
+            description = (_('Flavor %(flavor)s could not be created, '
                              'error:%(msg)s') %
                            dict(flavor=flavor, msg=str(ex)))
             LOG.exception(description)
-            raise falcon.HTTPBadRequest(_('Unable to create'), description)
+            raise falcon.HTTPBadRequest(
+                title=_('Unable to create'), description=description)
         capabilities = self._pools_ctrl.capabilities(name=pool_list[0])
         try:
             self._ctrl.create(flavor,
@@ -212,20 +214,22 @@ class Resource(object):
             response.status = falcon.HTTP_201
             response.location = request.path
         except errors.ConnectionError as ex:
-            description = (_(u'Flavor %(flavor)s could not be created, '
+            description = (_('Flavor %(flavor)s could not be created, '
                              'error:%(msg)s') %
                            dict(flavor=flavor, msg=str(ex)))
             LOG.exception(description)
-            raise falcon.HTTPBadRequest(_('Unable to create'), description)
+            raise falcon.HTTPBadRequest(
+                title=_('Unable to create'), description=description)
         # NOTE(gengchc2): Update the 'flavor' field in pools tables.
         try:
             self._update_pools_by_flavor(flavor, pool_list)
         except errors.ConnectionError as ex:
-            description = (_(u'Flavor %(flavor)s could not be created, '
+            description = (_('Flavor %(flavor)s could not be created, '
                              'error:%(msg)s') %
                            dict(flavor=flavor, msg=str(ex)))
             LOG.exception(description)
-            raise falcon.HTTPBadRequest(_('Unable to create'), description)
+            raise falcon.HTTPBadRequest(
+                title=_('Unable to create'), description=description)
 
     @decorators.TransportLog("Flavors item")
     @acl.enforce("flavors:create")
@@ -241,7 +245,7 @@ class Resource(object):
         :returns: HTTP | [201, 400]
         """
 
-        LOG.debug(u'PUT flavor - name: %s', flavor)
+        LOG.debug('PUT flavor - name: %s', flavor)
 
         data = wsgi_utils.load(request)
         wsgi_utils.validate(self._validators['create'], data)
@@ -258,17 +262,18 @@ class Resource(object):
         :returns: HTTP | [204]
         """
 
-        LOG.debug(u'DELETE flavor - name: %s', flavor)
+        LOG.debug('DELETE flavor - name: %s', flavor)
         # NOTE(gengchc2): If configuration flavor is
         # used by the new schema, the flavor field in pools
         # need to be cleaned.
         try:
             self._clean_pools_by_flavor(flavor)
         except errors.ConnectionError:
-            description = (_(u'Flavor %(flavor)s could not be deleted.') %
+            description = (_('Flavor %(flavor)s could not be deleted.') %
                            dict(flavor=flavor))
             LOG.exception(description)
-            raise falcon.HTTPBadRequest(_('Unable to create'), description)
+            raise falcon.HTTPBadRequest(
+                title=_('Unable to create'), description=description)
         self._ctrl.delete(flavor, project=project_id)
         response.status = falcon.HTTP_204
 
@@ -278,7 +283,8 @@ class Resource(object):
         if len(pool_list) == 0:
             response.status = falcon.HTTP_400
             response.location = request.path
-            raise falcon.HTTPBadRequest(_('Unable to create'), 'Bad Request')
+            raise falcon.HTTPBadRequest(
+                title=_('Unable to create'), description='Bad Request')
         # NOTE(gengchc2): If the flavor does not exist, return
         try:
             self._ctrl.get(flavor, project=project_id)
@@ -295,11 +301,12 @@ class Resource(object):
         try:
             self._check_pools_exists(pool_list)
         except errors.PoolDoesNotExist as ex:
-            description = (_(u'Flavor %(flavor)s cant be updated, '
+            description = (_('Flavor %(flavor)s cant be updated, '
                              'error:%(msg)s') %
                            dict(flavor=flavor, msg=str(ex)))
             LOG.exception(description)
-            raise falcon.HTTPBadRequest(_('updatefail'), description)
+            raise falcon.HTTPBadRequest(
+                title=_('updatefail'), description=description)
         capabilities = self._pools_ctrl.capabilities(name=pool_list[0])
         try:
             self._ctrl.update(flavor, project=project_id,
@@ -314,11 +321,12 @@ class Resource(object):
         try:
             self._update_pools_by_flavor(flavor, pool_list)
         except errors.ConnectionError as ex:
-            description = (_(u'Flavor %(flavor)s could not be updated, '
+            description = (_('Flavor %(flavor)s could not be updated, '
                              'error:%(msg)s') %
                            dict(flavor=flavor, msg=str(ex)))
             LOG.exception(description)
-            raise falcon.HTTPBadRequest(_('Unable to create'), description)
+            raise falcon.HTTPBadRequest(
+                title=_('Unable to create'), description=description)
         # (gengchc) Remove flavor from old pool list.
         try:
             pool_list_removed = []
@@ -327,14 +335,15 @@ class Resource(object):
                     pool_list_removed.append(pool_old['name'])
             self._clean_pools_by_flavor(flavor, pool_list_removed)
         except errors.ConnectionError as ex:
-            description = (_(u'Flavor %(flavor)s could not be updated, '
+            description = (_('Flavor %(flavor)s could not be updated, '
                              'error:%(msg)s') %
                            dict(flavor=flavor, msg=str(ex)))
             LOG.exception(description)
-            raise falcon.HTTPBadRequest(_('Unable to create'), description)
+            raise falcon.HTTPBadRequest(
+                title=_('Unable to create'), description=description)
         resp_data['pool_list'] = pool_list
         resp_data['href'] = request.path
-        response.body = transport_utils.to_json(resp_data)
+        response.text = transport_utils.to_json(resp_data)
 
     @decorators.TransportLog("Flavors item")
     @acl.enforce("flavors:update")
@@ -349,11 +358,11 @@ class Resource(object):
 
         :returns: HTTP | [200, 400]
         """
-        LOG.debug(u'PATCH flavor - name: %s', flavor)
+        LOG.debug('PATCH flavor - name: %s', flavor)
         data = wsgi_utils.load(request)
         field = 'pool_list'
         if field not in data:
-            LOG.debug(u'PATCH flavor, bad params')
+            LOG.debug('PATCH flavor, bad params')
             raise wsgi_errors.HTTPBadRequestBody(
                 '`pool_list` needs to be specified'
             )
