@@ -28,7 +28,8 @@ following fields are required:
     }
 
 Furthermore, depending on the underlying storage type of pool being
-registered, there is an optional field::
+registered, there is an optional field:
+::
 
     {
         "options": {...}
@@ -40,10 +41,14 @@ import jsonschema
 from oslo_log import log
 
 from zaqar.common.api.schemas import pools as schema
+from zaqar.common import decorators
 from zaqar.common import utils as common_utils
+from zaqar.i18n import _
 from zaqar.storage import errors
 from zaqar.storage import utils as storage_utils
+from zaqar.transport import acl
 from zaqar.transport import utils as transport_utils
+from zaqar.transport import validation
 from zaqar.transport.wsgi import errors as wsgi_errors
 from zaqar.transport.wsgi import utils as wsgi_utils
 
@@ -56,9 +61,12 @@ class Listing(object):
     :param pools_controller: means to interact with storage
     """
 
-    def __init__(self, pools_controller):
+    def __init__(self, pools_controller, validate):
         self._ctrl = pools_controller
+        self._validate = validate
 
+    @decorators.TransportLog("Pools collection")
+    @acl.enforce("pools:get_all")
     def on_get(self, request, response, project_id):
         """Returns a pool listing as objects embedded in an object:
 
@@ -77,18 +85,23 @@ class Listing(object):
         :returns: HTTP | 200
         """
 
-        LOG.debug(u'LIST pools')
+        LOG.debug('LIST pools')
 
         store = {}
         request.get_param('marker', store=store)
         request.get_param_as_int('limit', store=store)
         request.get_param_as_bool('detailed', store=store)
 
-        cursor = self._ctrl.list(**store)
+        try:
+            self._validate.pool_listing(**store)
+        except validation.ValidationFailed as ex:
+            LOG.debug(ex)
+            raise wsgi_errors.HTTPBadRequestAPI(str(ex))
 
+        cursor = self._ctrl.list(**store)
         pools = list(next(cursor))
 
-        results = {}
+        results = {'links': []}
 
         if pools:
             store['marker'] = next(cursor)
@@ -96,16 +109,17 @@ class Listing(object):
             for entry in pools:
                 entry['href'] = request.path + '/' + entry['name']
 
-        results['links'] = [
-            {
-                'rel': 'next',
-                'href': request.path + falcon.to_query_str(store)
-            }
-        ]
+            results['links'] = [
+                {
+                    'rel': 'next',
+                    'href': request.path + falcon.to_query_str(store)
+                }
+            ]
+
         results['pools'] = pools
 
         response.content_location = request.relative_uri
-        response.body = transport_utils.to_json(results)
+        response.text = transport_utils.to_json(results)
         response.status = falcon.HTTP_200
 
 
@@ -121,10 +135,13 @@ class Resource(object):
         self._validators = {
             'weight': validator_type(schema.patch_weight),
             'uri': validator_type(schema.patch_uri),
+            'flavor': validator_type(schema.patch_flavor),
             'options': validator_type(schema.patch_options),
             'create': validator_type(schema.create)
         }
 
+    @decorators.TransportLog("Pools item")
+    @acl.enforce("pools:get")
     def on_get(self, request, response, project_id, pool):
         """Returns a JSON object for a single pool entry:
 
@@ -132,9 +149,10 @@ class Resource(object):
 
             {"weight": 100, "uri": "", options: {...}}
 
-            :returns: HTTP | [200, 404]
+        :returns: HTTP | [200, 404]
         """
-        LOG.debug(u'GET pool - name: %s', pool)
+
+        LOG.debug('GET pool - name: %s', pool)
         data = None
         detailed = request.get_param_as_bool('detailed') or False
 
@@ -147,9 +165,10 @@ class Resource(object):
 
         data['href'] = request.path
 
-        response.body = transport_utils.to_json(data)
-        response.content_location = request.relative_uri
+        response.text = transport_utils.to_json(data)
 
+    @decorators.TransportLog("Pools item")
+    @acl.enforce("pools:create")
     def on_put(self, request, response, project_id, pool):
         """Registers a new pool. Expects the following input:
 
@@ -162,7 +181,7 @@ class Resource(object):
         :returns: HTTP | [201, 204]
         """
 
-        LOG.debug(u'PUT pool - name: %s', pool)
+        LOG.debug('PUT pool - name: %s', pool)
 
         conf = self._ctrl.driver.conf
         data = wsgi_utils.load(request)
@@ -174,44 +193,64 @@ class Resource(object):
         try:
             self._ctrl.create(pool, weight=data['weight'],
                               uri=data['uri'],
+                              flavor=data.get('flavor', None),
                               options=data.get('options', {}))
             response.status = falcon.HTTP_201
             response.location = request.path
+        except errors.PoolCapabilitiesMismatch as e:
+            title = _('Unable to create pool')
+            LOG.exception(title)
+            raise falcon.HTTPBadRequest(title=title, description=str(e))
         except errors.PoolAlreadyExists as e:
             LOG.exception('Pool "%s" already exists', pool)
             raise wsgi_errors.HTTPConflict(str(e))
 
+    @decorators.TransportLog("Pools item")
+    @acl.enforce("pools:delete")
     def on_delete(self, request, response, project_id, pool):
         """Deregisters a pool.
 
-        :returns: HTTP | 204
+        :returns: HTTP | [204, 403]
         """
 
-        LOG.debug(u'DELETE pool - name: %s', pool)
-        self._ctrl.delete(pool)
+        LOG.debug('DELETE pool - name: %s', pool)
+
+        try:
+            self._ctrl.delete(pool)
+        except errors.PoolInUseByFlavor as ex:
+            title = _('Unable to delete')
+            description = _('This pool is used by flavors {flavor}; '
+                            'It cannot be deleted.')
+            description = description.format(flavor=ex.flavor)
+            LOG.exception(description)
+            raise falcon.HTTPForbidden(title=title, description=description)
+
         response.status = falcon.HTTP_204
 
+    @decorators.TransportLog("Pools item")
+    @acl.enforce("pools:update")
     def on_patch(self, request, response, project_id, pool):
         """Allows one to update a pool's weight, uri, and/or options.
 
         This method expects the user to submit a JSON object
-        containing at least one of: 'uri', 'weight', 'options'. If
-        none are found, the request is flagged as bad. There is also
-        strict format checking through the use of
+        containing at least one of: 'uri', 'weight', 'flavor',
+        'options'.If none are found, the request is flagged as bad.
+        There is also strict format checking through the use of
         jsonschema. Appropriate errors are returned in each case for
         badly formatted input.
 
         :returns: HTTP | 200,400
         """
 
-        LOG.debug(u'PATCH pool - name: %s', pool)
+        LOG.debug('PATCH pool - name: %s', pool)
         data = wsgi_utils.load(request)
 
-        EXPECT = ('weight', 'uri', 'options')
+        EXPECT = ('weight', 'uri', 'flavor', 'options')
         if not any([(field in data) for field in EXPECT]):
-            LOG.debug(u'PATCH pool, bad params')
+            LOG.debug('PATCH pool, bad params')
             raise wsgi_errors.HTTPBadRequestBody(
-                'One of `uri`, `weight`, or `options` needs '
+                'One of `uri`, `weight`, `flavor`,'
+                ' or `options` needs '
                 'to be specified'
             )
 
@@ -226,9 +265,13 @@ class Resource(object):
             )
         fields = common_utils.fields(data, EXPECT,
                                      pred=lambda v: v is not None)
-
+        resp_data = None
         try:
             self._ctrl.update(pool, **fields)
+            resp_data = self._ctrl.get(pool, False)
         except errors.PoolDoesNotExist as ex:
             LOG.exception('Pool "%s" does not exist', pool)
             raise wsgi_errors.HTTPNotFound(str(ex))
+
+        resp_data['href'] = request.path
+        response.text = transport_utils.to_json(resp_data)
