@@ -18,7 +18,6 @@ import falcon
 from oslo_log import log as logging
 from oslo_utils import netutils
 from oslo_utils import timeutils
-import six
 from stevedore import driver
 
 from zaqar.common import decorators
@@ -53,14 +52,14 @@ class ItemResource(object):
 
         except storage_errors.DoesNotExist as ex:
             LOG.debug(ex)
-            raise wsgi_errors.HTTPNotFound(six.text_type(ex))
+            raise wsgi_errors.HTTPNotFound(str(ex))
 
-        except Exception as ex:
-            LOG.exception(ex)
-            description = _(u'Subscription could not be retrieved.')
+        except Exception:
+            description = _('Subscription could not be retrieved.')
+            LOG.exception(description)
             raise wsgi_errors.HTTPServiceUnavailable(description)
 
-        resp.body = utils.to_json(resp_dict)
+        resp.text = utils.to_json(resp_dict)
         # status defaults to 200
 
     @decorators.TransportLog("Subscriptions item")
@@ -71,9 +70,9 @@ class ItemResource(object):
                                                  subscription_id,
                                                  project=project_id)
 
-        except Exception as ex:
-            LOG.exception(ex)
-            description = _(u'Subscription could not be deleted.')
+        except Exception:
+            description = _('Subscription could not be deleted.')
+            LOG.exception(description)
             raise wsgi_errors.HTTPServiceUnavailable(description)
 
         resp.status = falcon.HTTP_204
@@ -95,20 +94,21 @@ class ItemResource(object):
             resp.location = req.path
         except storage_errors.SubscriptionDoesNotExist as ex:
             LOG.debug(ex)
-            raise wsgi_errors.HTTPNotFound(six.text_type(ex))
+            raise wsgi_errors.HTTPNotFound(str(ex))
         except storage_errors.SubscriptionAlreadyExists as ex:
             LOG.debug(ex)
-            raise wsgi_errors.HTTPConflict(six.text_type(ex))
+            raise wsgi_errors.HTTPConflict(str(ex))
         except validation.ValidationFailed as ex:
             LOG.debug(ex)
-            raise wsgi_errors.HTTPBadRequestAPI(six.text_type(ex))
-        except Exception as ex:
-            LOG.exception(ex)
-            description = (_(u'Subscription %(subscription_id)s could not be'
+            raise wsgi_errors.HTTPBadRequestAPI(str(ex))
+        except Exception:
+            description = (_('Subscription %(subscription_id)s could not be'
                              ' updated.') %
                            dict(subscription_id=subscription_id))
-            raise falcon.HTTPBadRequest(_('Unable to update subscription'),
-                                        description)
+            LOG.exception(description)
+            raise falcon.HTTPBadRequest(
+                title=_('Unable to update subscription'),
+                description=description)
 
 
 class CollectionResource(object):
@@ -145,11 +145,11 @@ class CollectionResource(object):
             subscriptions = list(next(results))
         except validation.ValidationFailed as ex:
             LOG.debug(ex)
-            raise wsgi_errors.HTTPBadRequestAPI(six.text_type(ex))
+            raise wsgi_errors.HTTPBadRequestAPI(str(ex))
 
-        except Exception as ex:
-            LOG.exception(ex)
-            description = _(u'Subscriptions could not be listed.')
+        except Exception:
+            description = _('Subscriptions could not be listed.')
+            LOG.exception(description)
             raise wsgi_errors.HTTPServiceUnavailable(description)
 
         # Got some. Prepare the response.
@@ -168,7 +168,7 @@ class CollectionResource(object):
             'links': links
         }
 
-        resp.body = utils.to_json(response_body)
+        resp.text = utils.to_json(response_body)
         # status defaults to 200
 
     @decorators.TransportLog("Subscriptions collection")
@@ -200,14 +200,15 @@ class CollectionResource(object):
                                                            project=project_id)
         except validation.ValidationFailed as ex:
             LOG.debug(ex)
-            raise wsgi_errors.HTTPBadRequestAPI(six.text_type(ex))
-        except Exception as ex:
-            LOG.exception(ex)
-            description = _(u'Subscription could not be created.')
+            raise wsgi_errors.HTTPBadRequestAPI(str(ex))
+        except Exception:
+            description = _('Subscription could not be created.')
+            LOG.exception(description)
             raise wsgi_errors.HTTPServiceUnavailable(description)
 
         now = timeutils.utcnow_ts()
-        now_dt = datetime.datetime.utcfromtimestamp(now)
+        now_dt = datetime.datetime.fromtimestamp(
+            now, tz=datetime.timezone.utc).replace(tzinfo=None)
         expires = now_dt + datetime.timedelta(seconds=ttl)
         api_version = req.path.split('/')[1]
         if created:
@@ -221,16 +222,16 @@ class CollectionResource(object):
 
             resp.location = req.path
             resp.status = falcon.HTTP_201
-            resp.body = utils.to_json(
-                {'subscription_id': six.text_type(created)})
+            resp.text = utils.to_json(
+                {'subscription_id': str(created)})
         else:
             subscription = self._subscription_controller.get_with_subscriber(
                 queue_name, subscriber, project_id)
             confirmed = subscription.get('confirmed', True)
             if confirmed:
-                description = _(u'Such subscription already exists.'
-                                u'Subscriptions are unique by project + queue '
-                                u'+ subscriber URI.')
+                description = _('Such subscription already exists.'
+                                'Subscriptions are unique by project + queue '
+                                '+ subscriber URI.')
                 raise wsgi_errors.HTTPConflict(description,
                                                headers={'location': req.path})
             else:
@@ -242,8 +243,8 @@ class CollectionResource(object):
 
                 resp.location = req.path
                 resp.status = falcon.HTTP_201
-                resp.body = utils.to_json(
-                    {'subscription_id': six.text_type(subscription['id'])})
+                resp.text = utils.to_json(
+                    {'subscription_id': str(subscription['id'])})
 
 
 class ConfirmResource(object):
@@ -257,7 +258,7 @@ class ConfirmResource(object):
         self._notification = notifier.NotifierDriver()
         self._conf = conf
 
-    @decorators.TransportLog("Subscription confirmation item")
+    @decorators.TransportLog("Subscriptions confirmation item")
     @acl.enforce("subscription:confirm")
     def on_put(self, req, resp, project_id, queue_name, subscription_id):
         if req.content_length:
@@ -267,13 +268,14 @@ class ConfirmResource(object):
 
         try:
             self._validate.subscription_confirming(document)
-            confirmed = document.get('confirmed', None)
+            confirmed = document.get('confirmed')
             self._subscription_controller.confirm(queue_name, subscription_id,
                                                   project=project_id,
                                                   confirmed=confirmed)
             if confirmed is False:
                 now = timeutils.utcnow_ts()
-                now_dt = datetime.datetime.utcfromtimestamp(now)
+                now_dt = datetime.datetime.fromtimestamp(
+                    now, tz=datetime.timezone.utc).replace(tzinfo=None)
                 ttl = self._conf.transport.default_subscription_ttl
                 expires = now_dt + datetime.timedelta(seconds=ttl)
                 api_version = req.path.split('/')[1]
@@ -291,14 +293,15 @@ class ConfirmResource(object):
             resp.location = req.path
         except storage_errors.SubscriptionDoesNotExist as ex:
             LOG.debug(ex)
-            raise wsgi_errors.HTTPNotFound(six.text_type(ex))
+            raise wsgi_errors.HTTPNotFound(str(ex))
         except validation.ValidationFailed as ex:
             LOG.debug(ex)
-            raise wsgi_errors.HTTPBadRequestAPI(six.text_type(ex))
-        except Exception as ex:
-            LOG.exception(ex)
-            description = (_(u'Subscription %(subscription_id)s could not be'
+            raise wsgi_errors.HTTPBadRequestAPI(str(ex))
+        except Exception:
+            description = (_('Subscription %(subscription_id)s could not be'
                              ' confirmed.') %
                            dict(subscription_id=subscription_id))
-            raise falcon.HTTPBadRequest(_('Unable to confirm subscription'),
-                                        description)
+            LOG.exception(description)
+            raise falcon.HTTPBadRequest(
+                title=_('Unable to confirm subscription'),
+                description=description)
