@@ -15,13 +15,11 @@
 import falcon
 
 from zaqar.transport import utils
-from zaqar.transport.wsgi import v1_0
 from zaqar.transport.wsgi import v1_1
 from zaqar.transport.wsgi import v2_0
 
 VERSIONS = {
     'versions': [
-        v1_0.VERSION,
         v1_1.VERSION,
         v2_0.VERSION
     ]
@@ -34,6 +32,6 @@ class Resource(object):
         self.versions = utils.to_json(VERSIONS)
 
     def on_get(self, req, resp, project_id):
-        resp.body = self.versions
+        resp.text = self.versions
 
         resp.status = falcon.HTTP_300
